HiC_Plot_Heatmap <-
function(file, index=c(1,2,3),sep = "\t", header = TRUE,verbose = TRUE,negative.log10.scale=FALSE,xlab = "", ylab = "", main = "",cex.main=1,cex.lab=1, col=matlab.like(100)) 
{
    if (!file.exists(file)) {
        print("No file found in current directory")
        return(NULL)
    }
    Data = read.table(file, sep = sep, header = header)
    if (dim(Data)[2] < 3) {
        print("Error. One row must include at least 3 columns.")
        return(NULL)
    }
    if (length(index)!=3){
	  print("The specified index for fragment 1, fragment 2 and intensity should be equal to 3.")
        return(NULL)
    }
    if (max(index)>dim(Data)[2]){
	  print("The specified index is more than the number of columns in the data file.")
        return(NULL)
    }	
    if (verbose) {
        print(paste(dim(Data)[1], "observations are loaded...", 
            sep = " "))
    }
    if (verbose) {
        print("Preparing the matrix of intensities...")
    }
    fragIDs = unique(sort(c(Data[, index[1]], Data[, index[2]])))
    size = length(fragIDs)
    IntensityMatrix = array(NA, dim = c(size, size))
    rownames(IntensityMatrix) = fragIDs
    colnames(IntensityMatrix) = fragIDs
    for (i in 1:dim(Data)[1]) {
        IntensityMatrix[as.character(Data[i, index[1]]), as.character(Data[i, 
            index[2]])] = Data[i, index[3]]
    }
    if (negative.log10.scale)
     {IntensityMatrix=-log(IntensityMatrix)/log(10)}
	IntensityMatrix=IntensityMatrix[nrow(IntensityMatrix):1,] # Reverse rows.
     par(mar=c(5, 5, 4, 7)+0.1)
    image(1:nrow(IntensityMatrix), 1:ncol(IntensityMatrix), IntensityMatrix,cex.axis = 1,cex.main = cex.main, yaxt = "n", xaxt = "n", cex.lab = cex.lab, col= col, xlab=xlab , ylab=ylab , main=main )	##, yaxt = "n"
    axis(2, 1:nrow(IntensityMatrix), nrow(IntensityMatrix):1, cex.axis = 1,col.axis = "black")
    axis(1, 1:nrow(IntensityMatrix), 1:nrow(IntensityMatrix), cex.axis = 1,col.axis = "black")
    maxa=max(IntensityMatrix[!is.na(IntensityMatrix)]); mina=min(IntensityMatrix[!is.na(IntensityMatrix)]); mina=0; # 
    image.plot(legend.only = TRUE, col=col, zlim = c(mina, maxa), legend.width = 1, axis.args = list(at = seq(mina,maxa,length.out=6), labels = round(seq(mina,maxa,length.out=6),digits=3) ), legend.mar = 6.5)
}

